;;; consfigurator.el --- Utilities for working with Consfigurator consfigs

;; Author: Sean Whitton <spwhitton@spwhitton.name>
;; Version: 1.0.2

;; Copyright (C) 2021  Sean Whitton

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Code:

;;;###autoload
(defun activate-consfigurator-indentation-hints ()
  "Activate indentation hints for Consfigurator properties.

Note that these hints assume you're using the recommended consfig
defpackage, where the :consfigurator package is used unqualified,
and packages providing properties have local nicknames
corresponding to the final dot-delimited component of their names."
  (interactive)
  ;; Properties
  (put 'deploys. 'common-lisp-indent-function '2)
  (put 'deploys-these. 'common-lisp-indent-function '2)
  (put 'file:has-content 'common-lisp-indent-function '1)
  (put 'file:exists-with-content 'common-lisp-indent-function '1)
  (put 'file:contains-lines 'common-lisp-indent-function '1)
  (put 'apt:additional-sources 'common-lisp-indent-function '1)
  (put 'chroot:deploys. 'common-lisp-indent-function '2)
  (put 'chroot:deploys-these. 'common-lisp-indent-function '2)
  (put 'chroot:os-bootstrapped-for. 'common-lisp-indent-function '3)
  (put 'chroot:os-bootstrapped. 'common-lisp-indent-function '2)
  (put 'disk:debian-live-iso-built. 'common-lisp-indent-function '2)
  (put 'libvirt:kvm-boots-chroot-for. 'common-lisp-indent-function '2)
  (put 'libvirt:kvm-boots-chroot. 'common-lisp-indent-function '1)
  (put 'sbuild:built. 'common-lisp-indent-function '1)
  (put 'lxc:user-container-for. 'common-lisp-indent-function '3)
  (put 'lxc:user-container. 'common-lisp-indent-function '2)

  ;; Other operators
  (put 'with-unapply 'common-lisp-indent-function '(&body))
  (put 'os:typecase 'common-lisp-indent-function '(&rest (&whole 2 &rest 1)))
  (put 'os:etypecase 'common-lisp-indent-function '(&rest (&whole 2 &rest 1))))

(provide 'consfigurator)

;;; consfigurator.el ends here
